@@ -5,7 +5,7 @@ GLib.load_class :Variant
 module GLib
   # Overrides for GVariant, GLib's variant data type.
   class Variant
-    setup_instance_method! 'get_string'
+    setup_instance_method! "get_string"
 
     def get_string_with_override
       get_string_without_override.first
