@@ -63,7 +63,7 @@ module GObject
   end
 
   def self.signal_connect(object, detailed_signal, data = nil, after = false, &block)
-    raise ArgumentError, "Block needed" unless block_given?
+    block or raise ArgumentError, "Block needed"
 
     signal_name, = detailed_signal.split("::")
     sig_info = object.class.find_signal signal_name
@@ -86,13 +86,12 @@ module GObject
   load_class :ParamFlags
 
   # NOTE: This Lib module is set up in `gir_ffi-base/gobject/lib.rb`.
-  module Lib
+  Lib.class_eval do
     attach_function :g_object_ref_sink, [:pointer], :pointer
     attach_function :g_object_ref, [:pointer], :pointer
     attach_function :g_object_unref, [:pointer], :pointer
 
     attach_function :g_value_copy, [:pointer, :pointer], :void
-    attach_function :g_value_init, [:pointer, :size_t], :pointer
     attach_function :g_value_unset, [:pointer], :pointer
 
     attach_function :g_signal_connect_data,
@@ -106,7 +105,5 @@ module GObject
 
     attach_function :g_param_spec_ref, [:pointer], :pointer
     attach_function :g_param_spec_sink, [:pointer], :pointer
-
-    attach_function :g_type_class_ref, [:size_t], :pointer
   end
 end
