@@ -4,19 +4,26 @@ module GObjectIntrospection
   # Wraps GIBaseInfo struct, the base \type for all info types.
   # Decendant types will be implemented as needed.
   class IBaseInfo
-    def initialize(ptr, lib = Lib)
+    def initialize(ptr)
       raise ArgumentError, "ptr must not be null" if ptr.null?
 
-      ObjectSpace.define_finalizer self, self.class.make_finalizer(lib, ptr)
+      ObjectSpace.define_finalizer self, self.class.make_finalizer(ptr)
 
       @pointer = ptr
-      @lib = lib
     end
 
     attr_reader :pointer
 
-    def self.make_finalizer(lib, ptr)
-      proc { lib.g_base_info_unref ptr }
+    def self.make_finalizer(ptr)
+      proc { finalize ptr }
+    end
+
+    class << self
+      protected
+
+      def finalize(ptr)
+        Lib.g_base_info_unref ptr
+      end
     end
 
     def to_ptr
@@ -35,7 +42,7 @@ module GObjectIntrospection
     # Examples:
     #
     #   build_array_method :fields
-    #   build_array_mehtod :properties, :property
+    #   build_array_method :properties, :property
     #   build_array_method :get_methods
     #
     def self.build_array_method(method, single = nil)
@@ -44,12 +51,12 @@ module GObjectIntrospection
       single ||= method[0..-2]
       count = method.sub(/^(get_)?/, '\\1n_')
       class_eval <<-CODE, __FILE__, __LINE__ + 1
-        def #{method}
-          #{cache_ivar} ||=
-            (0..(#{count} - 1)).map do |i|
-              #{single} i
-            end
-        end
+        def #{method}                       # def fields
+          #{cache_ivar} ||=                 #   @fields_cache ||=
+            (0..(#{count} - 1)).map do |i|  #     (0..(n_fields - 1)).map do |i|
+              #{single} i                   #       field i
+            end                             #     end
+        end                                 # end
       CODE
     end
 
@@ -76,18 +83,18 @@ module GObjectIntrospection
       counter ||= "n_#{single}s"
       fetcher ||= single
       class_eval <<-CODE, __FILE__, __LINE__ + 1
-        def #{method}(name)
-          #{cache_ivar} ||= begin
-              hash = {}
-              #{counter}.times do |i|
-                it = #{fetcher}(i)
-                hash[it.name] = it
-              end
-              hash
-            end
-          name = name.to_s
-          #{cache_ivar}[name]
-        end
+        def #{method}(name)           # def find_field(name)
+          #{cache_ivar} ||= begin     #   @find_field_cache ||= begin
+              hash = {}               #       hash = {}
+              #{counter}.times do |i| #       n_fields.times do |i|
+                it = #{fetcher}(i)    #         it = field(i)
+                hash[it.name] = it    #         hash[it.name] = it
+              end                     #       end
+              hash                    #       hash
+            end                       #     end
+          name = name.to_s            #   name = name.to_s
+          #{cache_ivar}[name]         #   @find_field_cache[name]
+        end                           # end
       CODE
     end
 
@@ -110,9 +117,10 @@ module GObjectIntrospection
     def container
       @container ||= begin
                        ptr = Lib.g_base_info_get_container self
-                       return if ptr.null?
-                       Lib.g_base_info_ref ptr
-                       IRepository.wrap_ibaseinfo_pointer ptr
+                       unless ptr.null?
+                         Lib.g_base_info_ref ptr
+                         IRepository.wrap_ibaseinfo_pointer ptr
+                       end
                      end
     end
 
