@@ -1,15 +1,15 @@
 # frozen_string_literal: true
 
-require 'ffi-gobject_introspection/i_base_info'
-require 'ffi-gobject_introspection/i_type_info'
-require 'ffi-gobject_introspection/i_arg_info'
+require "ffi-gobject_introspection/i_base_info"
+require "ffi-gobject_introspection/i_type_info"
+require "ffi-gobject_introspection/i_arg_info"
 
 module GObjectIntrospection
   # Wraps a GICallableInfo struct; represents a callable, either
   # IFunctionInfo, ICallbackInfo or IVFuncInfo.
   class ICallableInfo < IBaseInfo
     def return_type
-      ITypeInfo.wrap Lib.g_callable_info_get_return_type(self)
+      @return_type ||= ITypeInfo.wrap Lib.g_callable_info_get_return_type(self)
     end
 
     def caller_owns
