@@ -4,8 +4,7 @@ module GirFFI
   # The ArrayElementConvertor class handles conversion from C array elements to
   # ruby values
   class ArrayElementConvertor
-    attr_reader :value_type
-    attr_reader :pointer
+    attr_reader :value_type, :pointer
 
     def initialize(type, ptr)
       @value_type = type
@@ -15,11 +14,11 @@ module GirFFI
     def to_ruby_value
       bare_value = to_value
       case value_type
-      when :utf8
+      when :utf8, :filename
         bare_value.to_utf8
       when Array
         value_type[1].wrap bare_value
-      when Class
+      when Module
         value_type.wrap bare_value
       else
         bare_value
