@@ -4,18 +4,9 @@ require "gir_ffi/class_base"
 
 module GirFFI
   # Base class for generated classes representing boxed types.
-  class BoxedBase < StructBase
-    def initialize
-      store_pointer(nil)
-    end
-
+  class BoxedBase < StructLikeBase
     def self.make_finalizer(struct)
-      proc do
-        if struct.owned?
-          struct.owned = nil
-          GObject.boxed_free gtype, struct.to_ptr
-        end
-      end
+      proc { finalize(struct) }
     end
 
     def self.copy(val)
@@ -23,6 +14,17 @@ module GirFFI
       wrap(ptr)
     end
 
+    class << self
+      protected
+
+      def finalize(struct)
+        struct.owned? or return
+
+        struct.owned = nil
+        GObject.boxed_free gtype, struct.to_ptr
+      end
+    end
+
     private
 
     def store_pointer(*)
