@@ -18,10 +18,10 @@ module GirFFI
       end
 
       def method_definition
-        code = "def #{qualified_method_name}"
-        code += "(#{method_arguments.join(', ')})" if method_arguments.any?
-        method_lines.each { |line| code += "\n  #{line}" }
-        code + "\nend\n"
+        code = +"def #{qualified_method_name}"
+        code << "(#{method_arguments.join(', ')})" if method_arguments.any?
+        method_lines.each { |line| code << "\n  #{line}" }
+        code << "\nend\n"
       end
 
       private
