@@ -18,6 +18,10 @@ module GirFFI
           ObjectBase
         end
 
+        def object_class_struct
+          GObject::TypeClass
+        end
+
         def ancestor_infos
           []
         end
@@ -32,7 +36,16 @@ module GirFFI
       end
 
       def object_class_struct
-        @object_class_struct ||= Builder.build_class object_class_struct_info
+        @object_class_struct ||=
+          begin
+            parent_struct = parent_builder.object_class_struct
+            if object_class_struct_info
+              StructBuilder.new(object_class_struct_info,
+                                superclass: parent_struct).build_class
+            else
+              parent_struct
+            end
+          end
       end
 
       def ancestor_infos
@@ -48,8 +61,7 @@ module GirFFI
       protected
 
       def object_class_struct_info
-        @object_class_struct_info ||=
-          info.class_struct || parent_builder.object_class_struct_info
+        @object_class_struct_info ||= info.class_struct
       end
 
       private
@@ -107,9 +119,9 @@ module GirFFI
         return if vfunc_name == invoker_name
 
         klass.class_eval <<-DEF, __FILE__, __LINE__ + 1
-          def #{vfunc_name} *args, &block
-            #{invoker_name}(*args, &block)
-          end
+          def #{vfunc_name} *args, &block   # def foo *args, &block
+            #{invoker_name}(*args, &block)  #   foo_invoker *args, &block
+          end                               # end
         DEF
       end
 
