@@ -12,6 +12,7 @@ module GirFFI
       end
 
       def setup_class
+        check_ancestry
         setup_layout
         register_type
         setup_constants
@@ -26,6 +27,12 @@ module GirFFI
 
       private
 
+      def check_ancestry
+        unless klass < GirFFI::ObjectBase
+          raise ArgumentError, "#{klass} is not a GObject class"
+        end
+      end
+
       def register_type
         @gtype = GObject.type_register_static(parent_gtype.to_i,
                                               info.g_name,
@@ -98,7 +105,7 @@ module GirFFI
       end
 
       def class_size
-        parent_gtype.class_size + interface_gtypes.map(&:class_size).inject(0, :+)
+        parent_gtype.class_size + interface_gtypes.sum(&:class_size)
       end
 
       def setup_properties(object_class_ptr)
