@@ -67,6 +67,8 @@ module GirFFI
           from_utf8_array ary
         when :gboolean
           from_boolean_array ary
+        when :guint8
+          from_char_array ary
         else
           from_basic_type_array type, ary
         end
@@ -75,9 +77,10 @@ module GirFFI
       def from_module_type_array(type, ary)
         if type == GObject::Value
           from_gvalue_array type, ary
-        elsif type < GirFFI::ClassBase
+        elsif type < GirFFI::ClassBase ||
+              type.singleton_class < GirFFI::InterfaceBase
           from_struct_array type, ary
-        elsif type.singleton_class.include? GirFFI::EnumBase
+        elsif type.singleton_class < GirFFI::EnumBase
           from_enum_array type, ary
         else
           raise NotImplementedError, type
@@ -92,6 +95,11 @@ module GirFFI
         from_basic_type_array :int, ary.map { |val| val ? 1 : 0 }
       end
 
+      def from_char_array(ary)
+        ary = ary.bytes if ary.is_a? String
+        from_basic_type_array :int8, ary
+      end
+
       def from_pointer_array(type, ary)
         from_basic_type_array :pointer, ary.map { |elem| from type, elem }
       end
