@@ -5,7 +5,7 @@ module GirFFI
     # Extensions for GObjectIntrospection::IPropertyInfo needed by GirFFI
     module IPropertyInfo
       def getter_name
-        name.tr('-', '_')
+        name.tr("-", "_")
       end
 
       def setter_name
@@ -15,4 +15,4 @@ module GirFFI
   end
 end
 
-GObjectIntrospection::IPropertyInfo.send :include, GirFFI::InfoExt::IPropertyInfo
+GObjectIntrospection::IPropertyInfo.include GirFFI::InfoExt::IPropertyInfo
