@@ -1,6 +1,6 @@
 # frozen_string_literal: true
 
-require 'gir_ffi/builder_helper'
+require "gir_ffi/builder_helper"
 
 module GirFFI
   module InfoExt
@@ -20,15 +20,14 @@ module GirFFI
 
       def find_instance_method(method)
         info = find_method method
-        return info if info && info.method?
+        return info if info&.method?
       end
 
       def find_method(_method)
-        raise 'Must be overridden in subclass'
+        raise "Must be overridden in subclass"
       end
     end
   end
 end
 
-GObjectIntrospection::IRegisteredTypeInfo.send :include,
-                                               GirFFI::InfoExt::IRegisteredTypeInfo
+GObjectIntrospection::IRegisteredTypeInfo.include GirFFI::InfoExt::IRegisteredTypeInfo
