@@ -16,7 +16,7 @@ module GirFFI
       end
 
       def invoker_name
-        invoker && invoker.name
+        invoker&.name
       end
 
       def has_invoker?
@@ -26,4 +26,4 @@ module GirFFI
   end
 end
 
-GObjectIntrospection::IVFuncInfo.send :include, GirFFI::InfoExt::IVFuncInfo
+GObjectIntrospection::IVFuncInfo.include GirFFI::InfoExt::IVFuncInfo
