@@ -18,6 +18,11 @@ module GirFFI
       send method_name, *arguments, &block
     end
 
+    # TODO: Unify with implementation in ObjectBase
+    def copy_value_to_pointer(value, pointer, offset = 0)
+      pointer.put_pointer offset, value.to_ptr
+    end
+
     def wrap(ptr)
       ptr.to_object
     end
