@@ -1,6 +1,6 @@
 # frozen_string_literal: true
 
-require 'gir_ffi/method_setup'
+require "gir_ffi/method_setup"
 
 module GirFFI
   # Base module for modules representing GLib namespaces.
