@@ -26,6 +26,7 @@ module GirFFI
 
     def each
       return if @ptr.null?
+
       offset = 0
       while (val = read_value(offset))
         offset += ffi_type_size
@@ -41,7 +42,7 @@ module GirFFI
 
     def read_value(offset)
       val = fetch_value(offset)
-      val unless val.zero?
+      val unless null_value? val
     end
 
     def getter_method
@@ -77,5 +78,29 @@ module GirFFI
     def ffi_type_size
       @ffi_type_size ||= FFI.type_size(ffi_type)
     end
+
+    def null_check_strategy
+      @null_check_strategy ||=
+        if ffi_type == :pointer
+          :pointer
+        elsif ffi_type.is_a? Symbol
+          :numeric
+        elsif ffi_type < GirFFI::ClassBase
+          :pointer
+        elsif ffi_type.singleton_class.include? GirFFI::EnumBase
+          :enum
+        end
+    end
+
+    def null_value?(val)
+      case null_check_strategy
+      when :pointer
+        val.null?
+      when :enum
+        ffi_type.to_native(val, nil) == 0
+      else
+        val == 0
+      end
+    end
   end
 end
